@@ -47,77 +47,75 @@
 
 /**
  * @name Tag definitions
- *
- * Htags generates HTML tag by default.
  */
 /** @{ */
-const char *html_begin		= "<html>";
+const char *html_begin		= "<html xmlns='http://www.w3.org/1999/xhtml'>";
 const char *html_end		= "</html>";
 const char *html_head_begin	= "<head>";
 const char *html_head_end	= "</head>";
 const char *html_title_begin	= "<title>";
 const char *html_title_end	= "</title>";
-const char *body_begin		= "<body text='#191970' bgcolor='#f5f5dc' vlink='gray'>";
+const char *body_begin		= "<body>";
 const char *body_end		= "</body>";
-const char *title_begin		= "<h1><font color='#cc0000'>";
-const char *title_end		= "</font></h1>";
-const char *header_begin	= "<h2>";
+const char *title_begin		= "<h1 class='title'>";
+const char *title_end		= "</h1>";
+const char *header_begin	= "<h2 class='header'>";
 const char *header_end		= "</h2>";
-const char *poweredby_begin	= "<div align='right'>";
+const char *poweredby_begin	= "<div class='poweredby'>";
 const char *poweredby_end	= "</div>";
-const char *cvslink_begin	= "<font size='-1'>";
-const char *cvslink_end		= "</font>";
-const char *caution_begin	= "<center>\n<blockquote>";
-const char *caution_end		= "</blockquote>\n</center>";
+const char *cvslink_begin	= "<span class='cvs'>";
+const char *cvslink_end		= "</span>";
+const char *caution_begin	= "<div class='caution'>";
+const char *caution_end		= "</div>";
 const char *list_begin		= "<ol>";
 const char *list_end		= "</ol>";
 const char *item_begin		= "<li>";
-const char *item_end		= "";
-const char *flist_begin		= "<table cellpadding='2' width='100%'>";
+const char *item_end		= "</li>";
+const char *flist_begin		= "<table class='flist'>";
 const char *flist_end		= "</table>";
-const char *fline_begin		= "<tr>";
+const char *fline_begin		= "<tr class='flist'>";
 const char *fline_end		= "</tr>";
-const char *fitem_begin		= "<td nowrap='nowrap'>";
+const char *fitem_begin		= "<td class='flist'>";
 const char *fitem_end		= "</td>";
 const char *define_list_begin	= "<dl>";
 const char *define_list_end	= "</dl>";
 const char *define_term_begin	= "<dt>";
-const char *define_term_end	= "";
+const char *define_term_end	= "</dt>";
 const char *define_desc_begin	= "<dd>";
-const char *define_desc_end	= "";
+const char *define_desc_end	= "</dd>";
 const char *table_begin		= "<table>";
 const char *table_end		= "</table>";
-const char *comment_begin	= "<i><font color='green'>";
-const char *comment_end		= "</font></i>";
-const char *sharp_begin		= "<font color='darkred'>";
-const char *sharp_end		= "</font>";
-const char *brace_begin		= "<font color='red'>";
-const char *brace_end		= "</font>";
+const char *comment_begin	= "<em class='comment'>";
+const char *comment_end		= "</em>";
+const char *sharp_begin		= "<em class='sharp'>";
+const char *sharp_end		= "</em>";
+const char *brace_begin		= "<em class='brace'>";
+const char *brace_end		= "</em>";
 const char *verbatim_begin	= "<pre>";
 const char *verbatim_end	= "</pre>";
-const char *reserved_begin	= "<b>";
-const char *reserved_end	= "</b>";
-const char *position_begin	= "<font color='gray'>";
-const char *position_end	= "</font>";
-const char *warned_line_begin	= "<font color='red'>";
-const char *warned_line_end	= "</font>";
-const char *current_line_begin	= "";
-const char *current_line_end	= "";
-const char *current_row_begin	= "<tr>";
+const char *reserved_begin	= "<strong class='reserved'>";
+const char *reserved_end	= "</strong>";
+const char *position_begin	= "<em class='position'>";
+const char *position_end	= "</em>";
+const char *warned_line_begin	= "<em class='warned'>";
+const char *warned_line_end	= "</em>";
+const char *current_line_begin	= "<span class='curline'>";
+const char *current_line_end	= "</span>";
+const char *current_row_begin	= "<tr class='curline'>";
 const char *current_row_end	= "</tr>";
-const char *error_begin		= "<h1><font color='#cc0000'>";
-const char *error_end		= "</font></h1>";
-const char *message_begin	= "<h3>";
+const char *error_begin		= "<h2 class='error'>";
+const char *error_end		= "</h2>";
+const char *message_begin	= "<h3 class='message'>";
 const char *message_end		= "</h3>";
-const char *string_begin	= "<u>";
-const char *string_end		= "</u>";
+const char *string_begin	= "<em class='string'>";
+const char *string_end		= "</em>";
 const char *quote_great		= "&gt;";
 const char *quote_little	= "&lt;";
 const char *quote_amp		= "&amp;";
 const char *quote_space		= "&nbsp;";
-const char *hr			= "<hr>";
-const char *br			= "<br>";
-const char *empty_element	= "";
+const char *hr			= "<hr />";
+const char *br			= "<br />";
+const char *empty_element	= " /";
 const char *noframes_begin	= "<noframes>";
 const char *noframes_end	= "</noframes>";
 /** @} */
@@ -174,75 +172,6 @@ setup_xhtml(void)
 {
 	if (!strcmp(xhtml_version, "1.1") && !Fflag)
 		strict_xhtml = 1;
-	html_begin		= "<html xmlns='http://www.w3.org/1999/xhtml'>";
-	html_end		= "</html>";
-	html_head_begin		= "<head>";
-	html_head_end		= "</head>";
-	html_title_begin	= "<title>";
-	html_title_end		= "</title>";
-	body_begin		= "<body>";
-	body_end		= "</body>";
-	title_begin		= "<h1 class='title'>";
-	title_end		= "</h1>";
-	header_begin		= "<h2 class='header'>";
-	header_end		= "</h2>";
-	poweredby_begin		= "<div class='poweredby'>";
-	poweredby_end		= "</div>";
-	cvslink_begin		= "<span class='cvs'>";
-	cvslink_end		= "</span>";
-	caution_begin		= "<div class='caution'>";
-	caution_end		= "</div>";
-	list_begin		= "<ol>";
-	list_end		= "</ol>";
-	item_begin		= "<li>";
-	item_end		= "</li>";
-	flist_begin		= "<table class='flist'>";
-	flist_end		= "</table>";
-	fline_begin		= "<tr class='flist'>";
-	fline_end		= "</tr>";
-	fitem_begin		= "<td class='flist'>";
-	fitem_end		= "</td>";
-	define_list_begin	= "<dl>";
-	define_list_end		= "</dl>";
-	define_term_begin	= "<dt>";
-	define_term_end		= "</dt>";
-	define_desc_begin	= "<dd>";
-	define_desc_end		= "</dd>";
-	table_begin		= "<table>";
-	table_end		= "</table>";
-	comment_begin		= "<em class='comment'>";
-	comment_end		= "</em>";
-	sharp_begin		= "<em class='sharp'>";
-	sharp_end		= "</em>";
-	brace_begin		= "<em class='brace'>";
-	brace_end		= "</em>";
-	verbatim_begin		= "<pre>";
-	verbatim_end		= "</pre>";
-	reserved_begin		= "<strong class='reserved'>";
-	reserved_end		= "</strong>";
-	position_begin		= "<em class='position'>";
-	position_end		= "</em>";
-	warned_line_begin	= "<em class='warned'>";
-	warned_line_end		= "</em>";
-	current_line_begin	= "<span class='curline'>";
-	current_line_end	= "</span>";
-	current_row_begin	= "<tr class='curline'>";
-	current_row_end		= "</tr>";
-	error_begin		= "<h2 class='error'>";
-	error_end		= "</h2>";
-	message_begin		= "<h3 class='message'>";
-	message_end		= "</h3>";
-	string_begin		= "<em class='string'>";
-	string_end		= "</em>";
-	quote_great		= "&gt;";
-	quote_little		= "&lt;";
-	quote_amp		= "&amp;";
-	quote_space		= "&nbsp;";
-	hr			= "<hr />";
-	br			= "<br />";
-	empty_element		= " /";
-	noframes_begin		= "<noframes>";
-	noframes_end		= "</noframes>";
 }
 /**
  * @name These methods is used to tell lex() the current path infomation.
