@@ -4,33 +4,37 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef _CONF_H_
 #define _CONF_H_
 
 #include "strbuf.h"
-/*
- * Access library for gtags.conf (.globalrc).
- * File format is a subset of XXXcap (termcap, printcap) file.
+/**
+ * @file
+ * Access library for @FILE{gtags.conf} (@FILE{.globalrc}).
+ * File format is a subset of @NAME{XXXcap} (@NAME{termcap}, @NAME{printcap}) file.
  */
 #define GTAGSCONF       "/etc/gtags.conf"
-#define OLD_GTAGSCONF   "/etc/global.conf"	/* for compatibility */
+
+				/** for compatibility */
+#define OLD_GTAGSCONF   "/etc/global.conf"
 #define DEBIANCONF      "/etc/gtags/gtags.conf"
-#define OLD_DEBIANCONF  "/etc/gtags/global.conf"/* for compatibility */
+
+				/** for compatibility */
+#define OLD_DEBIANCONF  "/etc/gtags/global.conf"
 #define GTAGSRC 	".globalrc"
 #ifdef __DJGPP__
 #define DOS_GTAGSRC	"_globalrc"
