@@ -3,19 +3,18 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,21 +38,34 @@
 
 extern char **environ;
 
-/*
+/**
  * set_env: put environment variable.
  *
- *	i)	var	environment variable
- *	i)	val	value
+ *	@param[in]	var	environment variable
+ *	@param[in]	val	value
+ *
+ * Machine independent version of @XREF{setenv,3}.
  */
 void
 set_env(const char *var, const char *val)
 {
-	setenv(var, val, 1);
-}
 /*
+ * sparc-sun-solaris2.6 doesn't have setenv(3).
+ */
+#ifdef HAVE_PUTENV
+	STRBUF *sb = strbuf_open(0);
+
+	strbuf_sprintf(sb, "%s=%s", var, val);
+	putenv(strbuf_value(sb));
+	/* Don't free memory. putenv(3) require it. */
+#else
+	setenv(var, val, 1);
+#endif
+}
+/**
  * get_home_directory: get environment dependent home directory.
  *
- *	r)	home directory
+ *	@return	home directory
  */
 char *
 get_home_directory(void)
@@ -65,7 +77,7 @@ get_home_directory(void)
 #endif
 }
 
-/*
+/**
  * env_size: calculate the size of area used by environment.
  */
 int
